@@ -74,7 +74,6 @@ class AgentLifeCycle:
                         None
         """
 
-
         if("COG_AGENT_CONTAINERS" in cfg.config and "COG_AGENT_IMAGES" in cfg.config):
             container_names = cfg.config["COG_AGENT_CONTAINERS"].split(";")
             image_names = cfg.config["COG_AGENT_IMAGES"].split(";")
@@ -127,7 +126,7 @@ class AgentLifeCycle:
 
                 Parameters:
                         args: populated argument namespace returned by `argparse.parse_args()`
-                
+
         """
         client = docker.from_env()
         # check status of cgs_agent
@@ -175,7 +174,7 @@ class AgentLifeCycle:
 
                 Parameters:
                         args: populated argument namespace returned by `argparse.parse_args()`
-                
+
         """
         # get latest log location
         latest_log_loc = object._get_latest_log_loc(args)
@@ -203,7 +202,7 @@ class AgentLifeCycle:
 
                 Parameters:
                         logs: container logs
-                
+
         """
         logs_lines = logs.splitlines()
         # parse logs to get current status
@@ -280,9 +279,9 @@ class AgentLifeCycle:
         If `args` has parameter `datadog`/`agents` it will stop only datadog/containers.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
-                        result (bool): True if succeeded            
+                        result (bool): True if succeeded
         """
         if(args.agents or (hasattr(args, 'list') and len(args.list) > 0)):
             print("Stopping agents")
@@ -308,9 +307,9 @@ class AgentLifeCycle:
         Stops the containers listed in `args.list`.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
-                        result (bool): True if succeeded            
+                        result (bool): True if succeeded
         """
 
         # if list of agents is not specified, restart all
@@ -340,9 +339,9 @@ class AgentLifeCycle:
         Starts the containers listed in `args.list`.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
-                        result (bool): True if succeeded            
+                        result (bool): True if succeeded
         """
         # if list of agents is not specified, restart all
         if(not hasattr(args, 'list') or len(args.list) == 0):
@@ -399,7 +398,8 @@ class AgentLifeCycle:
                 options["environment"] = args.config.config
                 options["restart_policy"] = {"Name": "unless-stopped"}
                 options["tty"] = True
-                options["log_config"] = LogConfig(type=LogConfig.types.JSON, config={'max-size': '5m'})
+                options["log_config"] = LogConfig(
+                    type=LogConfig.types.JSON, config={'max-size': '5m'})
                 command = options.pop("command")
                 container = client.containers.run(
                     object._docker_images[container_name], command, **options)
@@ -421,7 +421,7 @@ class AgentLifeCycle:
         Stops datadog.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
                         result (bool): True if succeeded
         """
@@ -435,7 +435,7 @@ class AgentLifeCycle:
         Starts datadog.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
                         result (bool): True if succeeded
         """
@@ -449,7 +449,7 @@ class AgentLifeCycle:
         Prints datadog status.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
                         result (bool): True if succeeded
         """
@@ -470,9 +470,9 @@ class AgentLifeCycle:
         Starts Orbitty.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
-                        None           
+                        None
         """
         os.system("xhost +local:root")
         client = docker.from_env()
@@ -509,9 +509,9 @@ class AgentLifeCycle:
         Pulls docker images listed in `COG_AGENT_IMAGES`.
 
                 Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`    
+                        args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
-                        result (bool): True if succeeded           
+                        result (bool): True if succeeded
         """
         # Attempt to login to ECR client
         login_success = object._ecr_login(args)
@@ -544,17 +544,17 @@ class AgentLifeCycle:
                     if("status" not in status):
                         status["status"] = "Error"
                     terminal_size = shutil.get_terminal_size().columns
-
                     progress = ""
                     if("progressDetail" in status and "total" in status["progressDetail"]):
                         progress = generate_progress_bar(
                             status["progressDetail"]["current"], status["progressDetail"]["total"], 1, 10)
-                    status = "[" + str(i) + "/" + str(N) + "] " + image_name_short + \
-                        " - " + status["status"] + " " + progress
-                    print('{:{terminal_size}.{terminal_size}}'.format(
-                        status, terminal_size=terminal_size), end="\r", flush=True)
-                print("[" + str(i) + "/" + str(N) + "] " + image_name_short +
-                      " - " + bcolors.OKBLUE + "OK" + bcolors.ENDC + "\033[K")
+                        status = "[" + str(i) + "/" + str(N) + "] " + image_name_short + \
+                            " - " + status["status"] + " " + progress
+                        if(terminal_size > 0):
+                            print('{:{terminal_size}.{terminal_size}}'.format(
+                                status, terminal_size=terminal_size), end="\r", flush=True)
+                        else:
+                            print('{:{trm_sz}.{trm_sz}}'.format(status, trm_sz=80), end="\r", flush=True)
             except docker.errors.ImageNotFound:
                 print("[" + str(i) + "/" + str(N) + "] " + image_name_short +
                       " - " + bcolors.FAIL + "FAILED" + bcolors.ENDC + "\033[K")
@@ -578,7 +578,7 @@ class AgentLifeCycle:
         """
         # Get config
         local_cfg = config_obj.fetch_aws_keys()
-        if local_cfg==False:
+        if local_cfg == False:
             return False
         if 'SessionToken' in local_cfg:
             object.ecr_client = boto3.client(
@@ -604,7 +604,7 @@ class AgentLifeCycle:
         """
         # Construct client
         result = object._construct_ecr_client(args.config)
-        if result==False:
+        if result == False:
             return False
         num_retries = 3
         for trial in range(num_retries):
