@@ -18,12 +18,47 @@ import time
 
 
 class Configuration:
+    """
+    A class to manage agent and Cognicept's configuration
+    ...
+
+    Parameters
+    ----------
+    None
+
+    Methods
+    -------    
+    load_config(path):
+        Loads and parses `runtime.env` file into `object.config` located at `path`.
+    configure(args):
+        Manages cognicept configuration based on values in `args`.
+    save_config():
+        Saves configuration into `runtime.env` file.
+    get_cognicept_credentials():
+        Checks and returns `COGNICEPT_ACCESS_KEY` from configuration.
+    get_cognicept_api_uri():
+        Checks and returns `COGNICEPT_API_URI` from configuration.
+    get_field():
+        Returns single config value
+    configure_ssh():
+        Function to setup ssh access for the host machine given user input.
+    is_ssh_enabled(args):
+        Checks and returns value of `COG_ENABLE_SSH_KEY_AUTH` as bool.
+    cognicept_key_rotate:
+        Rotates AWS temporary keys retriving them from Cognicept API.
+    """
     config_path = os.path.expanduser("~/.cognicept/")
     env_path = config_path + "runtime.env"
     _regex_key = r"^([_A-Z0-9]+)$"
     _config_loaded = False
 
     def load_config(object, path):
+        """
+        Loads and parses `runtime.env` file into `object.config` located at `path`.
+
+                Parameters:
+                        path (str): Cognicept path, e.g. `~/.cognicept/`.                
+        """
         object.config_path = os.path.expanduser(path)
         object.env_path = object.config_path + "runtime.env"
         file = Path(object.env_path)
@@ -43,6 +78,15 @@ class Configuration:
         return True
 
     def configure(object, args):
+        """
+        Manages cognicept configuration based on values in `args`:
+            * If `args.read` is True, then it prints all configuration,
+            * If `args.add` is True, then it will add or modify a single value inputed by user,
+            * Otherwise it will iterate through all values and asks for modifications.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`            
+        """
         if(not object._config_loaded):
             return
 
@@ -92,6 +136,12 @@ class Configuration:
         object.save_config()
 
     def save_config(object):
+        """
+        Saves configuration into `runtime.env` file
+
+                Parameters:
+                    None
+        """
         try:
             with open(object.env_path, 'w') as file:
                 for key, value in object.config.items():
@@ -101,24 +151,52 @@ class Configuration:
                   "`. Please check write permission or run with `sudo`.")
 
     def get_cognicept_credentials(object):
+        """
+        Checks and returns `COGNICEPT_ACCESS_KEY` from configuration.
+
+                Returns:
+                    cognicept_access_key (str): value of `COGNICEPT_ACCESS_KEY`
+        """
         if "COGNICEPT_ACCESS_KEY" in object.config:
             return object.config["COGNICEPT_ACCESS_KEY"]
         else:
             print('COGNICEPT_ACCESS_KEY missing')
 
     def get_cognicept_api_uri(object):
+        """
+        Checks and returns `COGNICEPT_API_URI` from configuration.
+
+                Returns:
+                    cognicept_api_uri (str): value of `COGNICEPT_API_URI`, defaults to "https://app.cognicept.systems/api/v1/"
+        """
         if "COGNICEPT_API_URI" in object.config:
             return object.config["COGNICEPT_API_URI"]
         else:
             return "https://app.cognicept.systems/api/v1/"
 
     def get_field(object, field_name):
+        """
+        Returns single config value
+
+                Parameters:
+                        field_name (str): name of config field
+                Returns:
+                        value (str): value
+        """
         if field_name in object.config:
             return object.config[field_name]
         else:
             raise KeyError(field_name)
 
-    def interpret_bool_input(object, input_string):
+    def _interpret_bool_input(object, input_string):
+        """
+        Parses user input string bool value 
+
+                Parameters:
+                        input_string (str): input value
+                Returns:
+                        bool_value (bool): True if value is 'Y'
+        """
         if(input_string == 'Y'):
             return True
         elif(input_string == 'n'):
@@ -127,11 +205,19 @@ class Configuration:
             return None
 
     def configure_ssh(object):
+        """
+        Function to setup ssh access for the host machine given user input
+
+                Parameters:
+                        None
+                Returns:
+                        result (bool): True if some step didn't fail
+        """
         print('SSH is used to access the host machine from the isolated docker environment of Cognicept agent.')
 
         enable_ssh = None
         while(enable_ssh == None):
-            enable_ssh = object.interpret_bool_input(
+            enable_ssh = object._interpret_bool_input(
                 input("Enable SSH access? (Y/n):"))
 
         if(not enable_ssh):
@@ -155,7 +241,7 @@ class Configuration:
 
         enable_ssh_key = None
         while(enable_ssh_key == None):
-            enable_ssh_key = object.interpret_bool_input(
+            enable_ssh_key = object._interpret_bool_input(
                 input("Generate SSH key and give access? (Y/n):"))
 
         if(not enable_ssh_key):
@@ -222,7 +308,7 @@ class Configuration:
 
         enable_automatic_ssh = None
         while(enable_automatic_ssh == None):
-            enable_automatic_ssh = object.interpret_bool_input(
+            enable_automatic_ssh = object._interpret_bool_input(
                 input("Enable automatic ssh access? (Y/n):"))
 
         if(not enable_automatic_ssh):
@@ -234,13 +320,29 @@ class Configuration:
         return True
 
     def is_ssh_enabled(object):
+        """
+        Checks and returns value of `COG_ENABLE_SSH_KEY_AUTH` as bool
+
+                Parameters:
+                        None
+                Returns:
+                        ssh_enabled (bool): True if ssh is enables
+        """
         if(not "COG_ENABLE_SSH_KEY_AUTH" in object.config):
             return False
 
         return object.config["COG_ENABLE_SSH_KEY_AUTH"]
 
-    def cognicept_key_rotate(object, args):
-        print("Updating cloud credentials.")
+
+    def fetch_aws_keys(object):
+        """
+        Fetch AWS temporary keys retriving them from Cognicept API.
+
+                Parameters:
+                        
+                Returns:
+                        result (json): AWS temporary credentials returned from Cognicept API
+        """
         try:
             headers = {
                 'Authorization': 'Basic ' + object.get_cognicept_credentials()
@@ -250,14 +352,42 @@ class Configuration:
             if resp.status_code != 200:
                 print('Login error: wrong credentials.')
                 return False
+            return resp.json()            
+        except requests.exceptions.Timeout:
+            print("Cognicept REST API error: time out.")
+            return False
+        except requests.exceptions.TooManyRedirects:
+            print("Cognicept REST API error: Wrong endpoint.")
+            return False
+        except Exception as e:
+            print("Cognicept REST API error" + str(e))
+            return False
+        object.save_config()
 
-            object.config["AWS_ACCESS_KEY_ID"] = resp.json()[
+        return True
+
+    def cognicept_key_rotate(object, args):
+        """
+        Rotates AWS temporary keys retriving them from Cognicept API.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): True if succeeded
+        """
+        print("Updating cloud credentials.")
+        try:
+            response = object.fetch_aws_keys()
+            if response==False:
+                print("Error connecting Cognicept API. Please contact support@cognicept.systems")
+                return False
+            object.config["AWS_ACCESS_KEY_ID"] = response[
                 "AccessKeyId"]
-            object.config["AWS_SECRET_ACCESS_KEY"] = resp.json()[
+            object.config["AWS_SECRET_ACCESS_KEY"] = response[
                 "SecretAccessKey"]
-            object.config["AWS_SESSION_TOKEN"] = resp.json()[
+            object.config["AWS_SESSION_TOKEN"] = response[
                 "SessionToken"]
-            object.config["AWS_TOKEN_EXPIRATION"] = resp.json()[
+            object.config["AWS_TOKEN_EXPIRATION"] = response[
                 "Expiration"]
             print("Cloud access keys rotated successfully!")
         except requests.exceptions.Timeout:
